@@ -6,7 +6,6 @@ import sys
 import subprocess
 
 if __name__ == "__main__":
-
     root = abspath(dirname(__file__))
     os.chdir(root)
 
@@ -27,4 +26,4 @@ if __name__ == "__main__":
         env=env,
     )
 
-    subprocess.check_call([sys.executable, "-m", "py.test"])
+    subprocess.check_call([sys.executable, "-m", "pytest"])
